@@ -42,7 +42,7 @@ __WORKPATH__='./'
 __SHELLPATH__='./'
 __FILTERMODE__='half'
 __COLORFILTER__='$n0p'
-__SYSTEM_VARS__={'DEBUG':'off','TIMEOUT':30,'BACKSPACE':263,'TAB':9,'FASTUP':337,'FASTDOWN':336,'FLITERMODE':'half','DEBUGLEVEL':1,'__SAFEMODE__':'on','__STDOUT__':'$n0p','FLUSHCHECK':'off'}
+__SYSTEM_VARS__={'DEBUG':'off','TIMEOUT':30,'BACKSPACE':263,'TAB':9,'FASTUP':337,'FASTDOWN':336,'FILTERMODE':'half','DEBUGLEVEL':1,'__SAFEMODE__':'on','__STDOUT__':'$n0p','FLUSHCHECK':'off'}
 __COLORFILTERS__={'c3h7n3o9':[161,209,215,84,88,40,34,58],
 'rainbow':[161,209,215,192,84,88,82,40,28,56],
 'fak3':[483,484,485,486,487,488],
@@ -470,17 +470,6 @@ def realLength(target):
     for i in target:
         length+=getWidth(i)
     return length
-def _divideStrByRealLength(string,targetLength):
-    real_length=0
-    retStr=''
-    index=0
-    for i in string:
-        index+=1
-        real_length+=getWidth(i)
-        retStr+=i
-        if real_length>=targetLength:
-            return retStr,string[index:]
-    return '>>RETURN<<LINEHEAD>>FAILED<<','>>RETURN<<LINEHEAD>>FAILED<<'
 def verticalLine(_x,_y,TheChar,length,fColor=_grey):
     for i in range(0,length):
         say(_x,_y+i,TheChar,fColor)
@@ -566,13 +555,16 @@ def followSay(word,fColor=_white):
     say(__OUTX__,__OUTY__,word,fColor)
 def echo(content,color=_white,STDOUT='$n0p'):
     consoleOut('[Egg_002]:How can you see me!',content,'SPACE',color,COLORFILTER=True,STDOUT=STDOUT)
-def beNumber(ToBeNumber):
+def beNumber(ToBeNumber,default='$n0p'):
     try:
         ToBeNumber=int(ToBeNumber)
         return ToBeNumber
     except:
-        say(1,1,'Error:'+str(ToBeNumber)+' is not a legal number.',_red)
-        return '$n0p'
+        try:
+            ToBeNumber=float(ToBeNumber)
+            return ToBeNumber
+        except:
+            return default
 def sizeFormat(size, isDisk=False, precision=2):
     formats = ['KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
     unit = 1000.0 if isDisk else 1024.0
